@@ -15,11 +15,11 @@ PGObject::Util::LogRep::TestDecoding - Parse Pg's test_decoding messages
 
 =head1 VERSION
 
-Version 0.1.2
+Version 0.1.3
 
 =cut
 
-our $VERSION = '0.1.2';
+our $VERSION = '0.1.3';
 
 
 =head1 SYNOPSIS
@@ -142,6 +142,7 @@ my $grammar = <<'_ENDGRAMMAR' ;
            { $retval->{"type"} = "txn"; $retval; }
     dmlrec : header operation ":" col(s)
            { $retval->{"type"} = "dml"; $retval; }
+           { $retval->{"operation"} = $item{operation}; $retval }
     header : "table " schema "." tablename ": "
     col : column(s)
     schema : sqlident
@@ -161,7 +162,6 @@ my $grammar = <<'_ENDGRAMMAR' ;
            { $retval->{txnid} = $item[1]; $retval; }
     txncmd : "BEGIN" | "COMMIT"
     operation : "INSERT" | "UPDATE" | "DELETE"
-           { $retval->{"operation"} = $item{"operation"}; $retval }
 _ENDGRAMMAR
 
 
